@@ -1,17 +1,14 @@
 package App::Translit::String;
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Modules.
 use English;
 use Error::Pure qw(err);
 use Getopt::Std;
 use Lingua::Translit;
 
-# Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -44,7 +41,7 @@ sub run {
 		print STDERR "\t-t table\tTransliteration table (default ".
 			"value is 'ISO/R 9').\n";
 		print STDERR "\t--version\tPrint version.\n";
-		exit 1;
+		return 1;
 	}
 	$self->{'_string'} = $ARGV[0];
 
@@ -68,7 +65,7 @@ sub run {
 			'Error', $EVAL_ERROR;
 	}
 	print "$ret\n";
-	return;
+	return 0;
 }
 
 1;
@@ -86,6 +83,7 @@ App::Translit::String - Perl class for translit-string application.
 =head1 SYNOPSIS
 
  use App::Translit::String;
+
  my $obj = App::Translit::String->new;
  $obj->run;
 
@@ -112,11 +110,9 @@ App::Translit::String - Perl class for translit-string application.
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use App::Translit::String;
 
  # Run.
@@ -139,11 +135,9 @@ App::Translit::String - Perl class for translit-string application.
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use App::Translit::String;
 
  # Run.
@@ -162,21 +156,22 @@ L<Lingua::Translit>.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/App-Translit-String>.
+L<https://github.com/michal-josef-spacek/App-Translit-String>.
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2015-2016 Michal Špaček
- BSD 2-Clause License
+© 2015-2020 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
